InnovationMerge is an incredibly powerful Python library designed to revolutionize the creation of AI, IoT, and other cutting-edge projects that can seamlessly run on CPU, GPU, and Edge devices. With InnovationMerge, you can simplify and supercharge your development process, enabling you to bring your innovative ideas to life faster and more efficiently than ever before. 

## About
- `Author` : innovationmerge
- `Version`: 1.X.X
- `Description`: 
    - Contains innovationmerge projects core components. 
    - This package will include core components required to build AI, IoT and other Applications.

## Requirements: 
- `Python > 3.7`

## Install using pip
1. Install on `RaspberryPi`
    - `pip install innovationmerge[rpi]`

2. Install on `Windows`
    - `pip install innovationmerge[windows]`

## Install using Poetry
1. Install on `RaspberryPi`
    - `poetry add innovationmerge[rpi]`

2. Install on `Windows`
    - `poetry add innovationmerge[windows]`

## Install using source
1. Install on `RaspberryPi`
    - `poetry install --extras "rpi"` 

2. Install on `Windows`
    - `poetry install --extras "windows"` 

## Components
### Edge Computing - `EdgeObjectDetectionTfLite`
1. `Object Detection` - Currently SSD and MobileNet models are supported


## Projects
1. **[Predictive capture using Tensorflow and Raspberry Pi](https://www.innovationmerge.com/2023/10/08/predictive-capture-tensorflow-raspberrypi/)**
   - **Description:** This article explains how to segment audio into different regions using an open-source Python Library called pyAudioAnalysis.
   - [**Code Link**](https://github.com/innovationmerge/innovationmergeblog/tree/master/predictive_capture)